diff --git a/components/lib/organizationchart/OrganizationChartNode.vue b/components/lib/organizationchart/OrganizationChartNode.vue
index abc6c38164..b8fc71ee0e 100755
--- a/components/lib/organizationchart/OrganizationChartNode.vue
+++ b/components/lib/organizationchart/OrganizationChartNode.vue
@@ -5,32 +5,32 @@
['p-organizationchart-node', { 'p-organizationchart-node-selectable': instance.selectable, 'p-highlight': instance.selected }],
- nodeToggler: 'p-organizationchart-node-toggle-button',
- nodeTogglerIcon: 'p-organizationchart-node-toggle-button-icon',
- lines: 'p-organizationchart-connectors',
- lineDown: 'p-organizationchart-connector-down',
- lineLeft: ({ index }) => ['p-organizationchart-connector-left', { 'p-organizationchart-connector-top': !(index === 0) }],
- lineRight: ({ props, index }) => ['p-organizationchart-connector-right', { 'p-organizationchart-connector-top': !(index === props.node.children.length - 1) }],
- nodes: 'p-organizationchart-node-children'
+ nodeToggleButton: 'p-organizationchart-node-toggle-button',
+ nodeToggleButtonIcon: 'p-organizationchart-node-toggle-button-icon',
+ connectors: 'p-organizationchart-connectors',
+ connectorDown: 'p-organizationchart-connector-down',
+ connectorLeft: ({ index }) => ['p-organizationchart-connector-left', { 'p-organizationchart-connector-top': !(index === 0) }],
+ connectorRight: ({ props, index }) => ['p-organizationchart-connector-right', { 'p-organizationchart-connector-top': !(index === props.node.children.length - 1) }],
+ nodeChildren: 'p-organizationchart-node-children'
};
export default BaseStyle.extend({
diff --git a/components/lib/paginator/FirstPageLink.vue b/components/lib/paginator/FirstPageLink.vue
index ae204d77a4..ff463da4d1 100755
--- a/components/lib/paginator/FirstPageLink.vue
+++ b/components/lib/paginator/FirstPageLink.vue
@@ -1,6 +1,6 @@
-
-
+
+
diff --git a/components/lib/paginator/LastPageLink.vue b/components/lib/paginator/LastPageLink.vue
index 4e1a8c8cbf..b5af10c404 100755
--- a/components/lib/paginator/LastPageLink.vue
+++ b/components/lib/paginator/LastPageLink.vue
@@ -1,6 +1,6 @@
-
-
+
+
diff --git a/components/lib/paginator/NextPageLink.vue b/components/lib/paginator/NextPageLink.vue
index e6e82ad23f..b4d6c30b70 100755
--- a/components/lib/paginator/NextPageLink.vue
+++ b/components/lib/paginator/NextPageLink.vue
@@ -1,6 +1,6 @@
-
-
+
+
diff --git a/components/lib/paginator/PageLinks.vue b/components/lib/paginator/PageLinks.vue
index ade23189a0..150866d370 100755
--- a/components/lib/paginator/PageLinks.vue
+++ b/components/lib/paginator/PageLinks.vue
@@ -4,12 +4,12 @@
v-for="pageLink of value"
:key="pageLink"
v-ripple
- :class="cx('pageButton', { pageLink })"
+ :class="cx('page', { pageLink })"
type="button"
:aria-label="ariaPageLabel(pageLink)"
:aria-current="pageLink - 1 === page ? 'page' : undefined"
@click="onPageLinkClick($event, pageLink)"
- v-bind="getPTOptions(pageLink - 1, 'pageButton')"
+ v-bind="getPTOptions(pageLink - 1, 'page')"
:data-p-highlight="pageLink - 1 === page"
>
{{ pageLink }}
diff --git a/components/lib/paginator/Paginator.vue b/components/lib/paginator/Paginator.vue
index 93eb8e214f..8bc47861b1 100755
--- a/components/lib/paginator/Paginator.vue
+++ b/components/lib/paginator/Paginator.vue
@@ -1,7 +1,7 @@
-
+
@@ -47,7 +47,7 @@
/>
-
diff --git a/components/lib/paginator/PrevPageLink.vue b/components/lib/paginator/PrevPageLink.vue
index 85b5afab8c..b7a5726032 100755
--- a/components/lib/paginator/PrevPageLink.vue
+++ b/components/lib/paginator/PrevPageLink.vue
@@ -1,6 +1,6 @@
-
-
+
+
diff --git a/components/lib/paginator/style/PaginatorStyle.js b/components/lib/paginator/style/PaginatorStyle.js
index 2ec5a79c59..9df9770897 100644
--- a/components/lib/paginator/style/PaginatorStyle.js
+++ b/components/lib/paginator/style/PaginatorStyle.js
@@ -83,38 +83,38 @@ const classes = {
[`p-paginator-${key}`]: instance.hasBreakpoints()
}
],
- start: 'p-paginator-content-start',
- end: 'p-paginator-content-end',
- firstPageButton: ({ instance }) => [
+ contentStart: 'p-paginator-content-start',
+ contentEnd: 'p-paginator-content-end',
+ first: ({ instance }) => [
'p-paginator-first',
{
'p-disabled': instance.$attrs.disabled
}
],
- firstPageIcon: 'p-paginator-first-icon',
- previousPageButton: ({ instance }) => [
+ firstIcon: 'p-paginator-first-icon',
+ prev: ({ instance }) => [
'p-paginator-prev',
{
'p-disabled': instance.$attrs.disabled
}
],
- previousPageIcon: 'p-paginator-prev-icon',
- nextPageButton: ({ instance }) => [
+ prevIcon: 'p-paginator-prev-icon',
+ next: ({ instance }) => [
'p-paginator-next',
{
'p-disabled': instance.$attrs.disabled
}
],
- nextPageIcon: 'p-paginator-next-icon',
- lastPageButton: ({ instance }) => [
+ nextIcon: 'p-paginator-next-icon',
+ last: ({ instance }) => [
'p-paginator-last',
{
'p-disabled': instance.$attrs.disabled
}
],
- lastPageIcon: 'p-paginator-last-icon',
+ lastIcon: 'p-paginator-last-icon',
pages: 'p-paginator-pages',
- pageButton: ({ props, pageLink }) => [
+ page: ({ props, pageLink }) => [
'p-paginator-page',
{
'p-paginator-page-active': pageLink - 1 === props.page
diff --git a/components/lib/picklist/PickList.vue b/components/lib/picklist/PickList.vue
index 9b7a71d0ed..2924a995ac 100755
--- a/components/lib/picklist/PickList.vue
+++ b/components/lib/picklist/PickList.vue
@@ -32,7 +32,7 @@
-
+
-
+
@@ -96,7 +96,7 @@
-
+
`
const classes = {
root: 'p-picklist p-component',
sourceControls: 'p-picklist-controls p-picklist-source-controls',
- sourceWrapper: 'p-picklist-list-container p-picklist-source-list-container',
- buttons: 'p-picklist-controls p-picklist-transfer-controls',
- targetWrapper: 'p-picklist-list-container p-picklist-target-list-container',
+ sourceListContainer: 'p-picklist-list-container p-picklist-source-list-container',
+ transferControls: 'p-picklist-controls p-picklist-transfer-controls',
+ targetListContainer: 'p-picklist-list-container p-picklist-target-list-container',
targetControls: 'p-picklist-controls p-picklist-target-controls'
};
diff --git a/components/lib/timeline/Timeline.vue b/components/lib/timeline/Timeline.vue
index 376137155b..3a0e20ea50 100644
--- a/components/lib/timeline/Timeline.vue
+++ b/components/lib/timeline/Timeline.vue
@@ -1,18 +1,18 @@
-
+
-
+
-
diff --git a/components/lib/timeline/style/TimelineStyle.js b/components/lib/timeline/style/TimelineStyle.js
index d4995e70ce..999c5e523a 100644
--- a/components/lib/timeline/style/TimelineStyle.js
+++ b/components/lib/timeline/style/TimelineStyle.js
@@ -157,11 +157,11 @@ const theme = ({ dt }) => `
const classes = {
root: ({ props }) => ['p-timeline p-component', 'p-timeline-' + props.align, 'p-timeline-' + props.layout],
event: 'p-timeline-event',
- opposite: 'p-timeline-event-opposite',
- separator: 'p-timeline-event-separator',
- marker: 'p-timeline-event-marker',
- connector: 'p-timeline-event-connector',
- content: 'p-timeline-event-content'
+ eventOpposite: 'p-timeline-event-opposite',
+ eventSeparator: 'p-timeline-event-separator',
+ eventMarker: 'p-timeline-event-marker',
+ eventConnector: 'p-timeline-event-connector',
+ eventContent: 'p-timeline-event-content'
};
export default BaseStyle.extend({
diff --git a/components/lib/organizationchart/OrganizationChart.d.ts b/components/lib/organizationchart/OrganizationChart.d.ts
index 8668268556..4d88dd5e6c 100755
--- a/components/lib/organizationchart/OrganizationChart.d.ts
+++ b/components/lib/organizationchart/OrganizationChart.d.ts
@@ -132,29 +132,37 @@ export interface OrganizationChartPassThroughOptions {
*/
node?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the nodeToggler's DOM element.
*/
- nodeToggler?: OrganizationChartPassThroughOptionType;
+ nodeToggleButton?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the nodeTogglerIcon's DOM element.
*/
- nodeTogglerIcon?: OrganizationChartPassThroughOptionType;
+ nodeToggleButtonIcon?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the lines's DOM element.
*/
- lines?: OrganizationChartPassThroughOptionType;
+ connectors?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the lineCell's DOM element.
*/
lineCell?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the lineDown's DOM element.
*/
- lineDown?: OrganizationChartPassThroughOptionType;
+ connectorDown?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the nodes's DOM element.
*/
- nodes?: OrganizationChartPassThroughOptionType;
+ connectorLeft?: OrganizationChartPassThroughOptionType;
+ /**
+ * Used to pass attributes to the connector right's DOM element.
+ */
+ connectorRight?: OrganizationChartPassThroughOptionType;
+ /**
+ * Used to pass attributes to the node children's DOM element.
+ */
+ nodeChildren?: OrganizationChartPassThroughOptionType;
/**
* Used to pass attributes to the nodeCell's DOM element.
*/
@@ -132,29 +132,37 @@ export interface OrganizationChartPassThroughOptions {
node?: OrganizationChartPassThroughOptionType;
/**
- * Used to pass attributes to the nodeToggler's DOM element.
+ * Used to pass attributes to the node toggle button's DOM element.
*/
@@ -132,29 +132,37 @@ export interface OrganizationChartPassThroughOptions {
/**
- * Used to pass attributes to the nodeTogglerIcon's DOM element.
+ * Used to pass attributes to the node toggle button icon's DOM element.
*/
@@ -132,29 +132,37 @@ export interface OrganizationChartPassThroughOptions {
/**
- * Used to pass attributes to the lines's DOM element.
+ * Used to pass attributes to the connectors's DOM element.
*/
@@ -132,29 +132,37 @@ export interface OrganizationChartPassThroughOptions {
lineCell?: OrganizationChartPassThroughOptionType;
/**
- * Used to pass attributes to the lineDown's DOM element.
+ * Used to pass attributes to the connector down's DOM element.
*/
@@ -132,29 +132,37 @@ export interface OrganizationChartPassThroughOptions {
/**
- * Used to pass attributes to the nodes's DOM element.
+ * Used to pass attributes to the connector left's DOM element.
*/
diff --git a/components/lib/paginator/Paginator.d.ts b/components/lib/paginator/Paginator.d.ts
index db1090ac56..644276fa91 100755
--- a/components/lib/paginator/Paginator.d.ts
+++ b/components/lib/paginator/Paginator.d.ts
@@ -74,41 +74,41 @@ export interface PaginatorPassThroughOptions {
*/
root?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the start's DOM element.
*/
- start?: PaginatorPassThroughOptionType;
+ contentStart?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the first page button's DOM element.
*/
- firstPageButton?: PaginatorPassThroughOptionType;
+ first?: PaginatorPassThroughOptionType;
/**
- * Used to pass attributes to the first page icon's DOM element.
+ * Used to pass attributes to the first icon's DOM element.
*/
- firstPageIcon?: PaginatorPassThroughOptionType;
+ firstIcon?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the prev page button's DOM element.
*/
- previousPageButton?: PaginatorPassThroughOptionType;
+ prev?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the prev page icon's DOM element.
*/
- previousPageIcon?: PaginatorPassThroughOptionType;
+ prevIcon?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the next page button's DOM element.
*/
- nextPageButton?: PaginatorPassThroughOptionType;
+ next?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the next page icon's DOM element.
*/
- nextPageIcon?: PaginatorPassThroughOptionType;
+ nextIcon?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the last page button's DOM element.
*/
- lastPageButton?: PaginatorPassThroughOptionType;
+ last?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the last page icon's DOM element.
*/
- lastPageIcon?: PaginatorPassThroughOptionType;
+ lastIcon?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the pages's DOM element.
*/
@@ -116,7 +116,7 @@ export interface PaginatorPassThroughOptions {
/**
* Used to pass attributes to the page button's DOM element.
*/
- pageButton?: PaginatorPassThroughOptionType;
+ page?: PaginatorPassThroughOptionType;
/**
* Used to pass attributes to the current's DOM element.
*/
@@ -137,9 +137,9 @@ export interface PaginatorPassThroughOptions {
*/
jumpToPageInput?: InputNumberPassThroughOptions;
/**
* Used to pass attributes to the end's DOM element.
*/
- end?: PaginatorPassThroughOptionType;
+ contentEnd?: PaginatorPassThroughOptionType;
/**
* Used to manage all lifecycle hooks.
* @see {@link BaseComponent.ComponentHooks}
@@ -74,41 +74,41 @@ export interface PaginatorPassThroughOptions {
root?: PaginatorPassThroughOptionType;
/**
- * Used to pass attributes to the start's DOM element.
+ * Used to pass attributes to the content start's DOM element.
*/
@@ -137,9 +137,9 @@ export interface PaginatorPassThroughOptions {
jumpToPageInput?: InputNumberPassThroughOptions;
/**
- * Used to pass attributes to the end's DOM element.
+ * Used to pass attributes to the content end's DOM element.
*/
diff --git a/components/lib/picklist/PickList.d.ts b/components/lib/picklist/PickList.d.ts
index a77ba9ac09..f8adf79e15 100755
--- a/components/lib/picklist/PickList.d.ts
+++ b/components/lib/picklist/PickList.d.ts
@@ -169,17 +169,17 @@ export interface PickListPassThroughOptions {
*/
sourceMoveBottomButton?: ButtonPassThroughOptions
;
/**
- * Used to pass attributes to the source wrapper's DOM element.
+ * Used to pass attributes to the source list containerr's DOM element.
*/
- sourceWrapper?: PickListPassThroughOptionType;
+ sourceListContainer?: PickListPassThroughOptionType;
/**
* Used to pass attributes to the source list's DOM element.
*/
sourceList?: PickListPassThroughOptionType;
/**
* Used to pass attributes to the buttons' DOM element.
*/
- buttons?: PickListPassThroughOptionType;
+ transferControls?: PickListPassThroughOptionType;
/**
* Used to pass attributes to the Button component.
*/
@@ -197,9 +197,9 @@ export interface PickListPassThroughOptions {
*/
moveAllToSourceButton?: ButtonPassThroughOptions;
/**
* Used to pass attributes to the target wrapper's DOM element.
*/
- targetWrapper?: PickListPassThroughOptionType;
+ targetListContainer?: PickListPassThroughOptionType;
/**
* Used to pass attributes to the target list's DOM element.
*/
@@ -169,17 +169,17 @@ export interface PickListPassThroughOptions {
sourceList?: PickListPassThroughOptionType;
/**
- * Used to pass attributes to the buttons' DOM element.
+ * Used to pass attributes to the transfer controls' DOM element.
*/
@@ -197,9 +197,9 @@ export interface PickListPassThroughOptions {
moveAllToSourceButton?: ButtonPassThroughOptions;
/**
- * Used to pass attributes to the target wrapper's DOM element.
+ * Used to pass attributes to the target list container's DOM element.
*/
diff --git a/components/lib/timeline/Timeline.d.ts b/components/lib/timeline/Timeline.d.ts
index 0819df339c..bfb83710da 100644
--- a/components/lib/timeline/Timeline.d.ts
+++ b/components/lib/timeline/Timeline.d.ts
@@ -57,25 +57,25 @@ export interface TimelinePassThroughOptions {
*/
event?: TimelinePassThroughOptionType;
/**
* Used to pass attributes to the opposite's DOM element.
*/
- opposite?: TimelinePassThroughOptionType;
+ eventOpposite?: TimelinePassThroughOptionType;
/**
* Used to pass attributes to the separator's DOM element.
*/
- separator?: TimelinePassThroughOptionType;
+ eventSeparator?: TimelinePassThroughOptionType;
/**
* Used to pass attributes to the marker's DOM element.
*/
- marker?: TimelinePassThroughOptionType;
+ eventMarker?: TimelinePassThroughOptionType;
/**
* Used to pass attributes to the connector's DOM element.
*/
- connector?: TimelinePassThroughOptionType;
+ eventConnector?: TimelinePassThroughOptionType;
/**
* Used to pass attributes to the content's DOM element.
*/
- content?: TimelinePassThroughOptionType;
+ eventContent?: TimelinePassThroughOptionType;
/**
* Used to manage all lifecycle hooks.
* @see {@link BaseComponent.ComponentHooks}
@@ -57,25 +57,25 @@ export interface TimelinePassThroughOptions {
event?: TimelinePassThroughOptionType;
/**
- * Used to pass attributes to the opposite's DOM element.
+ * Used to pass attributes to the event opposite's DOM element.
*/
@@ -57,25 +57,25 @@ export interface TimelinePassThroughOptions {
/**
- * Used to pass attributes to the separator's DOM element.
+ * Used to pass attributes to the event separator's DOM element.
*/
@@ -57,25 +57,25 @@ export interface TimelinePassThroughOptions {
/**
- * Used to pass attributes to the marker's DOM element.
+ * Used to pass attributes to the event marker's DOM element.
*/
@@ -57,25 +57,25 @@ export interface TimelinePassThroughOptions {
/**
- * Used to pass attributes to the connector's DOM element.
+ * Used to pass attributes to the event connector's DOM element.
*/
@@ -57,25 +57,25 @@ export interface TimelinePassThroughOptions {
/**
- * Used to pass attributes to the content's DOM element.
+ * Used to pass attributes to the event content's DOM element.
*/